summaryrefslogtreecommitdiff
path: root/include/ec_commands.h
diff options
context:
space:
mode:
authorravindr1 <ravindra@intel.com>2020-11-05 03:57:48 +0530
committerCommit Bot <commit-bot@chromium.org>2020-11-23 09:31:45 +0000
commit5e3ff7b30e7313aec7144d9ffdf166e0900e7435 (patch)
tree2ff5f8606448133bae290bf8c9b40c4a465181f9 /include/ec_commands.h
parent4a399faf37a8c14797ea9f60e6430e678e6f8a15 (diff)
downloadchrome-ec-5e3ff7b30e7313aec7144d9ffdf166e0900e7435.tar.gz
Ectool: support reboot AP from G3 state with configurable delay.
On using Ectool command - reboot_ap_on_g3 [<delay>] && shutdown -h now, AP must perform a reboot from G3 state to S0 state with configurable delay in seconds on it's next corresponding shutdown cycle. BUG=b:172885634 BRANCH=none TEST=Run Ectool command - reboot_ap_on_g3 50 && shutdown -h now. Change-Id: I2c5eb304d27a9647f0adc220d91de2d0b4061460 Signed-off-by: ravindr1 <ravindra@intel.corp-partner.google.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2528731 Reviewed-by: Keith Short <keithshort@chromium.org>
Diffstat (limited to 'include/ec_commands.h')
-rw-r--r--include/ec_commands.h16
1 files changed, 12 insertions, 4 deletions
diff --git a/include/ec_commands.h b/include/ec_commands.h
index 02e8dab7f2..f1aa73f7f2 100644
--- a/include/ec_commands.h
+++ b/include/ec_commands.h
@@ -6033,13 +6033,21 @@ struct ec_response_locate_chip {
*
* This command is used for validation purpose, where the AP needs to be
* returned back to S0 state from G3 state without using the servo to trigger
* wake events.For this,there is no request or response struct.
*
* Order of command usage:
* ectool reboot_ap_on_g3 && shutdown -h now
*/
#define EC_CMD_REBOOT_AP_ON_G3 0x0127
+struct ec_params_reboot_ap_on_g3_v1 {
+ /* configurable delay in seconds in G3 state */
+ uint32_t reboot_ap_at_g3_delay;
+} __ec_align4;
+
/*****************************************************************************/
/* Get PD port capabilities
*
@@ -6033,13 +6033,21 @@ struct ec_response_locate_chip {
* This command is used for validation purpose, where the AP needs to be
* returned back to S0 state from G3 state without using the servo to trigger
- * wake events.For this,there is no request or response struct.
- *
- * Order of command usage:
- * ectool reboot_ap_on_g3 && shutdown -h now
+ * wake events.
+ * - With command version 0:
+ * AP reboots immediately from G3
+ * command usage: ectool reboot_ap_on_g3 && shutdown -h now
+ * - With command version 1:
+ * AP reboots after the user specified delay
+ * command usage: ectool reboot_ap_on_g3 [<delay>] && shutdown -h now
*/
#define EC_CMD_REBOOT_AP_ON_G3 0x0127